# Generated by roxygen2: do not edit by hand

S3method(print,bucket_list)
S3method(print,rank_list)
S3method(question_is_correct,sortable_rank)
S3method(question_ui_completed,sortable_rank)
S3method(question_ui_initialize,sortable_rank)
S3method(question_ui_try_again,sortable_rank)
export(add_rank_list)
export(bucket_list)
export(chain_js_events)
export(enable_modules)
export(is_modules_enabled)
export(is_sortable_options)
export(question_rank)
export(rank_list)
export(render_sortable)
export(sortable_js)
export(sortable_js_capture_bucket_input)
export(sortable_js_capture_input)
export(sortable_options)
export(sortable_output)
export(update_bucket_list)
export(update_rank_list)
importFrom(assertthat,"on_failure<-")
importFrom(assertthat,assert_that)
importFrom(assertthat,is.string)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(learnr,disable_all_tags)
importFrom(learnr,mark_as)
importFrom(learnr,question_is_correct)
importFrom(learnr,question_is_valid)
importFrom(learnr,question_ui_completed)
importFrom(learnr,question_ui_initialize)
importFrom(learnr,question_ui_try_again)
importFrom(utils,modifyList)
